<!-- # Library Reference

This page contains an auto-generated summary of {{PyScanCf}}'s API. Every submodule is
documented separately.
-->
# API Reference Manual

This guide provides documentation for all modules, and functions,
within PyScanCf for those in the public API.

```{eval-rst}
.. currentmodule:: pyscancf
.. autofunction:: pyscancf.cfrad
.. autofunction:: pyscancf.get_grid
.. currentmodule:: maxcappi
.. autofunction:: maxcappi.plot_cappi
```
<!--
```{toctree}
:maxdepth: 2
maxcappi
```  -->
